FastCasPolicy

Enum FastCasPolicy 

pub enum FastCasPolicy {
    Once,
    Spin {
        max_attempts: u32,
    },
    SpinYield {
        spin_attempts: u32,
        max_attempts: u32,
    },
}
Retry policy used by crate::FastCas when compare-and-swap loses a race.

Variants



Once

Try the operation once and return conflict on the first failed CAS.



Spin

Retry immediately until CAS succeeds, the operation aborts, or the attempt budget is exhausted.

Fields

max_attempts: u32

Maximum number of CAS attempts, including the first attempt.



SpinYield

Spin for a short prefix, then yield between retries until the attempt budget is exhausted.

Fields

spin_attempts: u32

Number of attempts to run without yielding.

max_attempts: u32

Maximum number of CAS attempts, including the first attempt.

Implementations

Source

impl FastCasPolicy

pub const fn once() -> FastCasPolicy

Creates a policy that performs one CAS attempt.

Returns

A single-attempt policy.

pub const fn spin(max_attempts: u32) -> FastCasPolicy

Creates an immediate-spin retry policy.

Parameters
  • max_attempts: Maximum number of CAS attempts. Zero is normalized to one attempt.
Returns

A spin policy with a non-zero attempt budget.

pub const fn spin_yield(spin_attempts: u32, max_attempts: u32) -> FastCasPolicy

Creates a spin-then-yield retry policy.

Parameters
  • spin_attempts: Number of attempts to run before yielding.
  • max_attempts: Maximum number of CAS attempts. Zero is normalized to one attempt.
Returns

A spin-yield policy with a non-zero attempt budget.

pub const fn max_attempts(self) -> u32

Returns the maximum number of attempts allowed by this policy.

Returns

A non-zero attempt count.

pub const fn should_yield_before(self, next_attempt: u32) -> bool

Returns whether the caller should yield before the next attempt.

Parameters
  • next_attempt: One-based number of the next attempt to execute.
Returns

true when this policy should yield before next_attempt.