FastStateMachineBuildError

Enum FastStateMachineBuildError 

pub enum FastStateMachineBuildError {
    StateCountNotConfigured,
    EventCountNotConfigured,
    InvalidStateCount {
        count: usize,
    },
    InvalidEventCount {
        count: usize,
    },
    TransitionTableOverflow {
        state_count: usize,
        event_count: usize,
    },
    InitialStateOutOfRange {
        state: usize,
        state_count: usize,
    },
    FinalStateOutOfRange {
        state: usize,
        state_count: usize,
    },
    TransitionSourceOutOfRange {
        source_state: usize,
        state_count: usize,
    },
    TransitionEventOutOfRange {
        event: usize,
        event_count: usize,
    },
    TransitionTargetOutOfRange {
        target: usize,
        state_count: usize,
    },
    DuplicateTransition {
        source_state: usize,
        event: usize,
        existing_target: usize,
        new_target: usize,
    },
}
Error returned when fast state machine configuration is invalid.

Variants



StateCountNotConfigured

State count was not configured.



EventCountNotConfigured

Event count was not configured.



InvalidStateCount

State count must be greater than zero.

Fields

count: usize

Requested state count.



InvalidEventCount

Event count must be greater than zero.

Fields

count: usize

Requested event count.



TransitionTableOverflow

Transition transition-table size overflowed usize.

Fields

state_count: usize

The number of states.

event_count: usize

The number of events.



InitialStateOutOfRange

An initial state code exceeds the configured state count.

Fields

state: usize

The invalid initial state.

state_count: usize

Configured state count.



FinalStateOutOfRange

A final state code exceeds the configured state count.

Fields

state: usize

The invalid final state.

state_count: usize

Configured state count.



TransitionSourceOutOfRange

A transition source code exceeds the configured state count.

Fields

source_state: usize

The invalid source state.

state_count: usize

Configured state count.



TransitionEventOutOfRange

A transition event code exceeds the configured event count.

Fields

event: usize

The invalid event code.

event_count: usize

Configured event count.



TransitionTargetOutOfRange

A transition target code exceeds the configured state count.

Fields

target: usize

The invalid target state.

state_count: usize

Configured state count.



DuplicateTransition

Same (source, event) maps to two different targets.

Fields

source_state: usize

Source state.

event: usize

Event code.

existing_target: usize

Existing target.

new_target: usize

Conflicting target.