FastStateMachineError

Enum FastStateMachineError 

pub enum FastStateMachineError {
    UnknownState {
        state: usize,
    },
    UnknownTransition {
        source_state: usize,
        event: usize,
    },
    CasConflict {
        attempts: u32,
    },
}
Error returned when applying an event through a crate::FastStateMachine.

Variants



UnknownState

The current state code is not configured in the state machine.

Fields

state: usize

The unregistered current state code.



UnknownTransition

No transition is configured for the (state, event) pair.

Fields

source_state: usize

The source state code.

event: usize

The triggering event code.



CasConflict

CAS conflicts were exhausted before the update could be installed.

Fields

attempts: u32

The total number of CAS attempts executed.