StateMachineBuildError

Enum StateMachineBuildError 

pub enum StateMachineBuildError<S, E> {
    InitialStateNotRegistered {
        state: S,
    },
    FinalStateNotRegistered {
        state: S,
    },
    TransitionSourceNotRegistered {
        source: S,
        event: E,
        target: S,
    },
    TransitionTargetNotRegistered {
        source: S,
        event: E,
        target: S,
    },
    DuplicateTransition {
        source: S,
        event: E,
        existing_target: S,
        new_target: S,
    },
}
Error returned when state machine rules are internally inconsistent.

S is the state type and E is the event type.

Variants



InitialStateNotRegistered

An initial state was configured but not registered as a state.

Fields

state: S

The unregistered initial state.



FinalStateNotRegistered

A final state was configured but not registered as a state.

Fields

state: S

The unregistered final state.



TransitionSourceNotRegistered

A transition source was not registered as a state.

Fields

source: S

Source state of the invalid transition.

event: E

Event of the invalid transition.

target: S

Target state of the invalid transition.



TransitionTargetNotRegistered

A transition target was not registered as a state.

Fields

source: S

Source state of the invalid transition.

event: E

Event of the invalid transition.

target: S

Target state of the invalid transition.



DuplicateTransition

Two transitions use the same (source, event) with different targets.

Fields

source: S

Source state shared by both transitions.

event: E

Event shared by both transitions.

existing_target: S

Target registered first.

new_target: S

Conflicting target registered later.