StateMachineError

Enum StateMachineError 

pub enum StateMachineError<S, E>
where S: Debug, E: Debug,
{ UnknownState { state: S, }, UnknownTransition { source_state: S, event: E, }, CasConflict { attempts: u32, }, }
Error returned when an event cannot be applied to the current state.

S is the state type and E is the event type.

Variants



UnknownState

The current state is not registered in the state machine.

Fields

state: S

The unregistered current state.



UnknownTransition

There is no transition for the current state and event pair.

Fields

source_state: S

The current source state.

event: E

The event that was triggered.



CasConflict

CAS retry limits were exhausted before a transition could be installed.

Fields

attempts: u32

Number of attempts executed by the CAS executor.