pub struct FastStateMachineBuilder { /* private fields */ }Expand description
Builder for dense, integer-coded state machine rules.
Implementations
Sourceimpl FastStateMachineBuilder
impl FastStateMachineBuilder
Sourcepub const fn state_count(self, count: usize) -> Self
pub const fn state_count(self, count: usize) -> Self
Sets the number of state codes used by this machine.
Sourcepub const fn event_count(self, count: usize) -> Self
pub const fn event_count(self, count: usize) -> Self
Sets the number of event codes used by this machine.
Sourcepub fn initial_state(self, state: usize) -> Self
pub fn initial_state(self, state: usize) -> Self
Registers one initial state code.
Sourcepub fn initial_states(self, states: &[usize]) -> Self
pub fn initial_states(self, states: &[usize]) -> Self
Registers multiple initial state codes.
Sourcepub fn final_state(self, state: usize) -> Self
pub fn final_state(self, state: usize) -> Self
Registers one final state code.
Sourcepub fn final_states(self, states: &[usize]) -> Self
pub fn final_states(self, states: &[usize]) -> Self
Registers multiple final state codes.
Sourcepub fn transition(self, source: usize, event: usize, target: usize) -> Self
pub fn transition(self, source: usize, event: usize, target: usize) -> Self
Adds one transition by source state code, event code, and target state.
Sourcepub const fn cas_policy(self, cas_policy: FastCasPolicy) -> Self
pub const fn cas_policy(self, cas_policy: FastCasPolicy) -> Self
Sets the retry policy used by FastStateMachine for CAS conflicts.
Sourcepub fn build(self) -> Result<FastStateMachine, FastStateMachineBuildError>
pub fn build(self) -> Result<FastStateMachine, FastStateMachineBuildError>
Builds and validates an immutable fast state machine.