pub struct Transition<S, E> { /* private fields */ }Expand description
A directed transition in a finite state machine.
S is the state type and E is the event type. In normal use both are
small enum-like values that implement Copy, Eq, and Hash.
Implementations
Sourceimpl<S, E> Transition<S, E>
impl<S, E> Transition<S, E>
Sourcepub const fn source(&self) -> S
pub const fn source(&self) -> S
Returns the source state of this transition.
Returns
The state that must be current before this transition can be applied.