pub enum FastCasPolicy {
Once,
Spin {
max_attempts: u32,
},
SpinYield {
spin_attempts: u32,
max_attempts: u32,
},
}Expand description
Retry policy used by crate::FastCas when compare-and-swap loses a race.
Variants
Once
Try the operation once and return conflict on the first failed CAS.
Spin
Retry immediately until CAS succeeds, the operation aborts, or the attempt budget is exhausted.
SpinYield
Spin for a short prefix, then yield between retries until the attempt budget is exhausted.
Implementations
Sourceimpl FastCasPolicy
impl FastCasPolicy
Sourcepub const fn once() -> FastCasPolicy
pub const fn once() -> FastCasPolicy
Sourcepub const fn spin(max_attempts: u32) -> FastCasPolicy
pub const fn spin(max_attempts: u32) -> FastCasPolicy
Sourcepub const fn spin_yield(spin_attempts: u32, max_attempts: u32) -> FastCasPolicy
pub const fn spin_yield(spin_attempts: u32, max_attempts: u32) -> FastCasPolicy
Sourcepub const fn max_attempts(self) -> u32
pub const fn max_attempts(self) -> u32