pub enum FastStateMachineBuildError {
StateCountNotConfigured,
EventCountNotConfigured,
InvalidStateCount {
count: usize,
},
InvalidEventCount {
count: usize,
},
TransitionTableOverflow {
state_count: usize,
event_count: usize,
},
InitialStateOutOfRange {
state: usize,
state_count: usize,
},
FinalStateOutOfRange {
state: usize,
state_count: usize,
},
TransitionSourceOutOfRange {
source_state: usize,
state_count: usize,
},
TransitionEventOutOfRange {
event: usize,
event_count: usize,
},
TransitionTargetOutOfRange {
target: usize,
state_count: usize,
},
DuplicateTransition {
source_state: usize,
event: usize,
existing_target: usize,
new_target: usize,
},
}Expand description
Error returned when fast state machine configuration is invalid.
Variants
StateCountNotConfigured
State count was not configured.
EventCountNotConfigured
Event count was not configured.
InvalidStateCount
State count must be greater than zero.
InvalidEventCount
Event count must be greater than zero.
TransitionTableOverflow
Transition transition-table size overflowed usize.
InitialStateOutOfRange
An initial state code exceeds the configured state count.
FinalStateOutOfRange
A final state code exceeds the configured state count.
TransitionSourceOutOfRange
A transition source code exceeds the configured state count.
TransitionEventOutOfRange
A transition event code exceeds the configured event count.
TransitionTargetOutOfRange
A transition target code exceeds the configured state count.
DuplicateTransition
Same (source, event) maps to two different targets.