pub enum StateMachineBuildError<S, E> {
InitialStateNotRegistered {
state: S,
},
FinalStateNotRegistered {
state: S,
},
TransitionSourceNotRegistered {
source: S,
event: E,
target: S,
},
TransitionTargetNotRegistered {
source: S,
event: E,
target: S,
},
DuplicateTransition {
source: S,
event: E,
existing_target: S,
new_target: S,
},
}Expand description
Error returned when state machine rules are internally inconsistent.
S is the state type and E is the event type.
Variants
InitialStateNotRegistered
An initial state was configured but not registered as a state.
Fields

state: SThe unregistered initial state.
FinalStateNotRegistered
A final state was configured but not registered as a state.
Fields

state: SThe unregistered final state.
TransitionSourceNotRegistered
A transition source was not registered as a state.
Fields

source: SSource state of the invalid transition.

event: EEvent of the invalid transition.

target: STarget state of the invalid transition.
TransitionTargetNotRegistered
A transition target was not registered as a state.
Fields

source: SSource state of the invalid transition.

event: EEvent of the invalid transition.

target: STarget state of the invalid transition.
DuplicateTransition
Two transitions use the same (source, event) with different targets.